R/cdi_processing.R
append_relative_cdi_scores.RdAdds a relative cdi score indicating the percentage of total achievable points the subject got on each given measure
append_relative_cdi_scores(subjects_table)the input table with an added "cdi_relative" column that contains the percentage of total points gained in the given administrations