Check if a file exists with exact case sensitivity

file.exists.case.sensitive(...)

Arguments

...

character vectors, containing file paths

Value

logical value: TRUE if the file exists with the exact same case, FALSE otherwise

Examples

if (FALSE) { # \dontrun{
exists <- file.exists.case.sensitive("path/to/image.jpg")
} # }