Populate the provided cdi data with percentile values for that specific age, instrument_type, measure and language. Loosely based on the work from this repo https://github.com/kachergis/cdi-percentiles/tree/main by George Kachergis and Jess Mankewitz with advice from Virginia Marchman.
Source:R/cdi_processing.R
populate_cdi_percentiles.RdPopulate the provided cdi data with percentile values for that specific age, instrument_type, measure and language. Loosely based on the work from this repo https://github.com/kachergis/cdi-percentiles/tree/main by George Kachergis and Jess Mankewitz with advice from Virginia Marchman.
Value
the input table with added columns containing the reference age used, the reference year used, and both gender specific and general percentile values for the cdi score
Examples
if (FALSE) { # \dontrun{
full_cdi_data <- all_subjects %>%
unnest(subject_aux_data) %>%
filter(!is.na(cdi_responses)) %>%
unnest(cdi_responses) %>%
peekbankr::cleanup_cdi_data() %>%
peekbankr::populate_cdi_percentiles()
} # }