Connect to Peekbank

connect_to_peekbank(
  db_version = "current",
  db_args = NULL,
  compress = TRUE,
  host = NULL,
  port = NULL
)

Arguments

db_version

String of the name of database version to use

db_args

List with host, user, and password defined

compress

Flag to use compression protocol (defaults to TRUE)

host

Hostname of the Peekbank server to connect to (defaults hosted PB)

port

Port of the Peekbank DB to connect to (defaults to 3306)

Value

con A DBIConnection object for the peekbank database

Examples

if (FALSE) { # \dontrun{
con <- connect_to_peekbank(db_version = "current", db_args = NULL)
DBI::dbDisconnect(con)
} # }