Connect to Peekbank
connect_to_peekbank(
db_version = "current",
db_args = NULL,
compress = TRUE,
host = NULL,
port = NULL
)String of the name of database version to use
List with host, user, and password defined
Flag to use compression protocol (defaults to TRUE)
Hostname of the Peekbank server to connect to (defaults hosted PB)
Port of the Peekbank DB to connect to (defaults to 3306)
con A DBIConnection object for the peekbank database
if (FALSE) { # \dontrun{
con <- connect_to_peekbank(db_version = "current", db_args = NULL)
DBI::dbDisconnect(con)
} # }