R/peekds_validators.R
ds.validate_table.RdCheck if a dataframe/table is compliant to peekbank json before database import
ds.validate_table(
df_table,
table_type,
cdi_expected,
dir_csv,
is_null_field_required = TRUE
)the dataframe to be saved
the type of dataframe, for the most updated table types specified by schema, please use functionds.list_ds_tables()
specifies whether cdi_data is to be expected to be present in the imported data; only relevant for subjects table
the folder directory containing all the csv files, used for stimulus image path validation
by default is set to TRUE which means that all the columns in the json file are required; when user specifically sets this to FALSE, then the fields that are allowed null values are not required.
an empty string when the input data frame is compliant with json specification, such as having all the required columns, primary key field has unique values, etc. Otherwise, the function returns a list of messages describing detailed issues that needs to be fixed
if (FALSE) { # \dontrun{
is_valid <-ds.validate_table(df_table = df_table, table_type = "xy_data", cdi_expected = F, dir_csv = "../processed_data")
} # }