R/peekds_validators.R
file.exists.case.sensitive.RdCheck if a file exists with exact case sensitivity
file.exists.case.sensitive(...)logical value: TRUE if the file exists with the exact same case, FALSE otherwise
if (FALSE) { # \dontrun{
exists <- file.exists.case.sensitive("path/to/image.jpg")
} # }