R/peekbankr.R
get_subjects.Rd
Get subjects
get_subjects(connection = NULL)
A connection to the peekbank database
A tibble of Subjects data. Note that Subjects is a table used to link longitudinal Administrations, which is the primary table you probably want.
if (FALSE) { # \dontrun{ get_subjects() } # }