R/cdi_processing.R
populate_cdi_percentiles.RdPopulate the provided cdi data with percentile values for that specific age, instrument_type, measure and language. Loosely based on the work from this repo https://github.com/kachergis/cdi-percentiles/tree/main by George Kachergis and Jess Mankewitz with advice from Virginia Marchman.
populate_cdi_percentiles(subjects_table)the input table with added columns containing the reference age used, the reference year used, and both gender specific and general percentile values for the cdi score